"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImagePickerDelegateImpl = exports.RadImagepicker = void 0;
var rad_imagepicker_common_1 = require("./rad-imagepicker.common");
var frame = require("tns-core-modules/ui/frame");
var imageSource = require("tns-core-modules/image-source");
var imagePickerController;
function createImageSourceFromUIImage(image, i) {
    var paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, true);
    var documentsDirectory = paths.objectAtIndex(0);
    var documentsDirectoryNSString = NSString.stringWithString(documentsDirectory);
    var ms = new Date().getMilliseconds();
    var path = documentsDirectoryNSString.stringByAppendingPathComponent("status" + i + "-" + ms + ".jpeg");
    var data = UIImagePNGRepresentation(image);
    data.writeToFileAtomically(path, true);
    return imageSource.fromFile(path);
}
var RadImagepicker = (function (_super) {
    __extends(RadImagepicker, _super);
    function RadImagepicker() {
        return _super.call(this) || this;
    }
    RadImagepicker.prototype.pick = function (options) {
        return new Promise(function (resolve, reject) {
            var viewController = frame.topmost().currentPage.ios;
            imagePickerController = ImagePickerController.new();
            var config = Configuration.new();
            if (options) {
                if (options.doneButtonTitle) {
                    config.doneButtonTitle = options.doneButtonTitle;
                }
                if (options.noImagesTitle) {
                    config.noImagesTitle = options.noImagesTitle;
                }
                if (options.allowVideoSelection !== undefined) {
                    config.allowVideoSelection = options.allowVideoSelection;
                }
                if (options.recordLocation !== undefined) {
                    config.recordLocation = options.recordLocation;
                }
            }
            imagePickerController.initWithConfiguration(config);
            if (options && options.imageLimit > 0) {
                imagePickerController.imageLimit = options.imageLimit;
            }
            imagePickerController.delegate = ImagePickerDelegateImpl.new().initWithCallback(function (selectedImages) {
                imagePickerController = null;
                resolve(selectedImages);
            });
            viewController.presentViewControllerAnimatedCompletion(imagePickerController, true, null);
        });
    };
    return RadImagepicker;
}(rad_imagepicker_common_1.Common));
exports.RadImagepicker = RadImagepicker;
var ImagePickerDelegateImpl = (function (_super) {
    __extends(ImagePickerDelegateImpl, _super);
    function ImagePickerDelegateImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImagePickerDelegateImpl.new = function () {
        return _super.new.call(this);
    };
    ImagePickerDelegateImpl.prototype.initWithCallback = function (callback) {
        this._callback = callback;
        return this;
    };
    ImagePickerDelegateImpl.prototype.cancelButtonDidPress = function (imagePicker) {
        this._callback();
        var viewController = frame.topmost().currentPage.ios;
        viewController.dismissViewControllerAnimatedCompletion(true, null);
    };
    ImagePickerDelegateImpl.prototype.doneButtonDidPressImages = function (imagePicker, images) {
        var selectedImages = [];
        for (var i = 0; i < images.count; i++) {
            selectedImages.push(createImageSourceFromUIImage(images[i], i));
        }
        this._callback(selectedImages);
        var viewController = frame.topmost().currentPage.ios;
        viewController.dismissViewControllerAnimatedCompletion(true, null);
    };
    ImagePickerDelegateImpl.prototype.wrapperDidPressImages = function (imagePicker, images) {
        var viewController = frame.topmost().currentPage.ios;
        if (images.count < 1) {
            viewController.dismissViewControllerAnimatedCompletion(true, null);
        }
        else {
            var lightboxImages = [];
            for (var i = 0; i < images.count; i++) {
                var lb = new LightboxImage({
                    image: images[i],
                    text: null,
                    videoURL: null
                });
                lightboxImages.push(lb);
            }
            var lightbox = new LightboxController({
                images: lightboxImages,
                startIndex: 0
            });
            imagePickerController.presentViewControllerAnimatedCompletion(lightbox, true, null);
        }
    };
    ImagePickerDelegateImpl.ObjCProtocols = [ImagePickerDelegate];
    return ImagePickerDelegateImpl;
}(NSObject));
exports.ImagePickerDelegateImpl = ImagePickerDelegateImpl;
//# sourceMappingURL=rad-imagepicker.ios.js.map